Lua_PlayerReportWindow = class("Lua_PlayerReportWindow", Lua_Window);
function Lua_PlayerReportWindow:ctor()
    self:superCall("ctor");
    self.blackAlpha = 0.01;
    self.showBlackMask = true;
    self.windowName = "Lua_PlayerReportWindow";
    self.skinName = "PlayerReportWindow_skin";
end

function Lua_PlayerReportWindow:buildShowItem()
    self:superCall("buildShowItem");

    self.titleNameTxt:setLangValue(171058)
    self.newIndox = 0;
    self.recordList = Array();

    self.msgInput:setDefaultLangValue(171008)
    self.msgInput.text = "";
    self.msgInput.characterLimit = 100;
    self.msgInput.lineTypeValue = 1;

    self.dragContainer = Lua_DragContainer.new(self.content, 614, 211, Lua_AxisDefine.Vertical);
    self.dragContainer:setLocation(-5, -219, 0);

    self.checkBoxList = Array();
    for i = 1, 6 do
        local checkBox = UICreate.createCheckBox(self.content, LanUtil.getValue(171008+i), 0, 0, 100, 24);
        checkBox.txt.fontName = Lua_MyUISettings.defaultFontName;
        checkBox.txt.pivot = Lua_WindowUtil.getPivot(3);
        checkBox.txt.verticalOverflowValue = 1;
        checkBox:setStyle(2);
        checkBox.txt.colorStr = Lua_ColorDefine.transColorStr("5d452e");
        checkBox.txt.fontSize = 24;
        if i <= 3 then
            checkBox:setLocation(-282+(i-1)*215, 261, 0);
        else
            checkBox:setLocation(-282+(i-4)*215, 187, 0);
        end
        checkBox:addBoxChange(self,self.onBoxChange);
        self.checkBoxList:add(checkBox);
    end
    self.sureBtn:addClickFuntion(self, self.onSureBtnClick);

    self:addLuaEvent("CHATCHECKBOX_CHANGE", self, self.setChatRecordList);
end

function Lua_PlayerReportWindow:showWin(param)
    if type(param) == "table" then
        self.data = param;
        self:setWinData();
    end
end

function Lua_PlayerReportWindow:setWinData()
    self.nameStr.text = LanUtil.formateStr(171015, self.data.name);
    local chatList = DataCenter.chatData:getSingleMsgList(self.data.id);
    local len = chatList:getSize();
    for i = 1, len do
        self.dragContainer:addSubContainer(Lua_ChatRecordItem,chatList[i], false);
    end
    self.dragContainer:updateChildPos();
    if len <= 0 then
        self:showUI();
    end
end

function Lua_PlayerReportWindow:setChatRecordList(dic)
    if dic.state == true then
        self.recordList:add(dic.str);
    else
        self.recordList:removeItem(dic.str);
    end
end

--无发言内容
function Lua_PlayerReportWindow:showUI()
    self.showBg = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_012", 0, -259, 0, 0);
    self.showBg:setScale(0.8,0.8,0.8);

    self.tipsTxt = UICreate.createLabel(self.content, LanUtil.getValue(171047), 0, -285, 200, 45, 32);
    self.tipsTxt.pivot = UIUtils.Pivot.Center;
    self.tipsTxt.fontName = "huakang_font";
    self.tipsTxt.colorStr = Lua_ColorDefine.transColorStr("938680");
end

function Lua_PlayerReportWindow:onBoxChange(val)
    for i = 1, self.checkBoxList:getSize() do
        if self.checkBoxList[i].selected == true and i ~= self.oldIndex then
            self.newIndox = i;
            if self.oldIndex == nil then 
                self.oldIndex = i;
            end
        end
    end

    if self.oldIndex ~= self.newIndox then
        self.checkBoxList[self.oldIndex].selected = false;
        self.oldIndex = self.newIndox;
    end
end

function Lua_PlayerReportWindow:onSureBtnClick(go)
    local msgText = self.msgInput.text;
    local contentIsNotNull = msgText == "" or msgText == LanUtil.getValue(171006);
    if (not contentIsNotNull) and Lua_CommonUtil.checkIsInvalid(msgText) then
        return;
    end

    if self.newIndox == 0 then
        OperateAlert.showLangValue(171016);
        return;
    end
    if self.recordList:getSize() == 0 and contentIsNotNull then
        OperateAlert.showLangValue(171017);
        return;
    end
    local msg = ProtoPublic_pb.Proto10105007();
    msg.player_id = self.data.id;
    msg.reason_type = self.newIndox;
    msg.addition = msgText;
    msg.server_flag = self.data.server_flag;
    for i = 1, self.recordList:getSize() do
        msg.evidence:append(self.recordList[i]);
    end
    sendMsg(10105007,msg);
    Lua_WindowUtil.openWin("Lua_PlayerReportWindow", Lua_WinParam.ACTION_CLOSE);
end

function Lua_PlayerReportWindow:cleanChatVoBSelected()
    local chatVo;
    local chatList = DataCenter.chatData:getSingleMsgList(self.data.id);
    for i = 1, chatList:getSize() do
        chatVo = chatList[i];
        if chatVo ~= nil then
            chatVo.bSelectedReport = false;
        end
    end
end

function Lua_PlayerReportWindow:dispose()
    self:cleanChatVoBSelected();
    if self.recordList ~= nil then
        self.recordList:dispose();
        self.recordList:clear();
        self.recordList = nil;
    end

    if self.dragContainer ~= nil then
        self.dragContainer:dispose();
        self.dragContainer = nil;
    end

    if self.checkBoxList ~= nil then
        self.checkBoxList:dispose();
        self.checkBoxList:clear();
        self.checkBoxList = nil;
    end

    self.data = nil;
    self:superCall("dispose");
end



















Lua_ChatRecordItem = class("Lua_ChatRecordItem",Lua_DragContainerItem)

function Lua_ChatRecordItem:ctor(p)
    self:superCall("ctor",p);
end

function Lua_ChatRecordItem:buildShowItem()
    self:superCall("buildShowItem");

    self.chatBox = UICreate.createCheckBox(self.content, "", 0, 0, 100, 20);
    self.chatBox.txt.pivot = Lua_WindowUtil.getPivot(3);
    self.chatBox.txt.verticalOverflowValue = 1;
    self.chatBox.txt.fontName = Lua_MyUISettings.defaultFontName;
    self.chatBox.txt.fontSize = 24;
    self.chatBox.txt.mouseEnable = false;
    self.chatBox.txt.colorStr = Lua_ColorDefine.transColorStr("5d452e");
    self.chatBox:SetDimensions(550,55);
    self.chatBox:setStyle(2);
    self.chatBox:setLocation(30, 0, 0);
    self.chatBox:setScale(1, 1, 1);
    self.chatBox:addBoxChange(self,self.onCheckBoxChange);

end

function Lua_ChatRecordItem:setData(data)
    self.data = data;
    local bSelected = data.bSelectedReport;
    self.chatBox.selected = bSelected;
    self.chatBox.txt.text = LanUtil.formateStr(171050, LanUtil.getValue(171000 + data.channel), data.chat_player.name, data.content)
end

function Lua_ChatRecordItem:onCheckBoxChange(val)
    local bSelected =  not self.data.bSelectedReport;
    self.data.bSelectedReport = bSelected;
    self.chatBox.selected = bSelected;

    local dic = {};
    dic.str = self.chatBox.txt.text;
    dic.state = val;
    Lua_MsgUtil.callFunc("CHATCHECKBOX_CHANGE", dic);
end

function Lua_ChatRecordItem:getHeight()
    return 55;
end

function Lua_ChatRecordItem:dispose()
    self:superCall("dispose");
end